@@ -1,11 +1,9 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::OptionalFeature;
-# git description: v0.019-10-g6d7b0fc
-$Dist::Zilla::Plugin::OptionalFeature::VERSION = '0.020';
+package Dist::Zilla::Plugin::OptionalFeature; # git description: v0.020-10-ge385fd3
 # ABSTRACT: Specify prerequisites for optional features in your distribution
 # vim: set ts=8 sw=4 tw=78 et :
-
+our $VERSION = '0.021';
 use Moose;
 with
     'Dist::Zilla::Role::BeforeBuild',
@@ -49,6 +47,11 @@ has default => (
     # NO DEFAULT
 );
 
+has load_prereqs => (
+    is => 'ro', isa => Bool,
+    default => 1,
+);
+
 has _prereq_phase => (
     is => 'ro', isa => NonEmptySimpleStr,
     lazy => 1,
@@ -84,46 +87,43 @@ around BUILDARGS => sub
     # pull these out so they don't become part of our prereq list
     my ($zilla, $plugin_name) = delete @{$args}{qw(zilla plugin_name)};
 
-    my ($feature_name, $description, $always_recommend, $require_develop, $prompt, $default, $phase) =
-        delete @{$args}{qw(-name -description -always_recommend -require_develop -prompt -default -phase)};
-    my ($type) = grep { defined } delete @{$args}{qw(-type -relationship)};
+    my %opts = (
+        map { exists $args->{$_} ? ( substr($_, 1) => delete($args->{$_}) ) : () }
+        qw(-name -description -always_recommend -require_develop -prompt -default -load_prereqs -phase -type));
+    $opts{type} //= delete $args->{'-relationship'} if defined $args->{'-relationship'};
 
     my @other_options = grep { /^-/ } keys %$args;
     delete @{$args}{@other_options};
     warn "[OptionalFeature] warning: unrecognized option(s): @other_options" if @other_options;
 
     # handle magic plugin names
-    if ((not $feature_name or not $phase or not $type)
+    if ((not $opts{name} or not $opts{phase} or not $opts{type})
             # plugin comes from a bundle
         and $plugin_name !~ m! (?: \A | / ) OptionalFeature \z !x)
     {
-        $feature_name ||= $plugin_name;
+        $opts{name} ||= $plugin_name;
 
-        if ($feature_name =~ / -
+        if ($opts{name} =~ / -
                 (Build|Test|Runtime|Configure|Develop)
                 (Requires|Recommends|Suggests|Conflicts)?
             \z/xp)
         {
-            $feature_name = ${^PREMATCH};
-            $phase ||= lc($1) if $1;
-            $type = lc($2) if $2;
+            $opts{name} = ${^PREMATCH};
+            $opts{phase} ||= lc($1) if $1;
+            $opts{type} = lc($2) if $2;
         }
     }
 
     confess 'optional features may not use the configure phase'
-        if $phase and $phase eq 'configure';
+        if $opts{phase} and $opts{phase} eq 'configure';
+
+    $opts{_prereq_phase} = delete $opts{phase} if exists $opts{phase};
+    $opts{_prereq_type} = delete $opts{type} if exists $opts{type};
 
     return {
         zilla => $zilla,
         plugin_name => $plugin_name,
-        defined $feature_name ? ( name => $feature_name ) : (),
-        defined $description ? ( description => $description ) : (),
-        defined $always_recommend ? ( always_recommend => $always_recommend ) : (),
-        defined $require_develop ? ( require_develop => $require_develop ) : (),
-        defined $prompt ? ( prompt => $prompt ) : (),
-        defined $default ? ( default => $default ) : (),
-        defined $phase ? ( _prereq_phase => $phase ) : (),
-        defined $type ? ( _prereq_type => $type ) : (),
+        %opts,
         _prereqs => $args,
     };
 };
@@ -150,6 +150,11 @@ has _dynamicprereqs_prompt => (
         my @assignments = map {
             qq!\$WriteMakefileArgs{$mm_key}{'$_'} = \$FallbackPrereqs{'$_'} = '${ \$self->_prereq_version($_) }'!
         } sort $self->_prereq_modules;
+        my $require_clause = !$self->load_prereqs ? ''
+            : ('eval "' . join('', map {
+                my $version = $self->_prereq_version($_);
+                "require $_; " . ($version ? "$_->VERSION('$version'); " : '')
+            } sort $self->_prereq_modules) . '1"' . "\n    || ");
 
         # TODO: in the future, [DynamicPrereqs] will have more sophisticated
         # options, so we would just need to pass the prompt text, default
@@ -157,11 +162,11 @@ has _dynamicprereqs_prompt => (
         [
             @assignments > 1
                 ? (
-                    'if (' . $prompt . ') {',   # to mollify vim
+                    'if (' . $require_clause . $prompt . ') {',   # to mollify vim
                     (map { '  ' . $_ . ';' } @assignments),
                     '}',
                   )
-                : ( @assignments, '  if ' . $prompt . ';' )
+                : ( @assignments, '  if ' . $require_clause . $prompt . ';' )
         ];
     },
 );
@@ -208,6 +213,7 @@ around dump_config => sub
     $config->{+__PACKAGE__} = {
         (map { $_ => $self->$_ }
             qw(name description always_recommend require_develop prompt)),
+        $self->prompt ? ( load_prereqs => $self->load_prereqs ) : (),
         # FIXME: YAML::Tiny does not handle leading - properly yet
         # (map { defined $self->$_ ? ( '-' . $_ => $self->$_ ) : () }
         (map { defined $self->$_ ? ( $_ => $self->$_ ) : () } qw(default)),
@@ -280,7 +286,7 @@ Dist::Zilla::Plugin::OptionalFeature - Specify prerequisites for optional featur
 
 =head1 VERSION
 
-version 0.020
+version 0.021
 
 =head1 SYNOPSIS
 
@@ -391,14 +397,18 @@ Defaults to the feature name, if not provided.
 If set with a true value, the prerequisites are added to the distribution's
 metadata as recommended prerequisites (e.g. L<cpanminus> will install
 recommendations with C<--with-recommends>, even when running
-non-interactively). Defaults to false, but I recommend you turn this on.
+non-interactively).
+
+Defaults to C<false>, but I recommend you turn this on.
 
 =item * C<-require_develop>
 
 If set with a true value, the prerequisites are added to the distribution's
 metadata as develop requires prerequisites (e.g. L<cpanminus> will install
 recommendations with C<--with-develop>, even when running
-non-interactively).  Defaults to true.
+non-interactively).
+
+Defaults to C<true>.
 
 =item * C<-prompt>
 
@@ -407,6 +417,19 @@ non-interactively).  Defaults to true.
 If set with a true value, F<Makefile.PL> is modified to include interactive
 prompts.
 
+Default is C<true> if C<-relationship> is C<requires>.
+C<false> otherwise.
+
+=item * C<-load_prereqs>
+
+(Available since version 0.021)
+
+If set, and C<-prompt> is also set, the prerequisites to be added by the feature
+are checked for in the Perl installation; if the requirements are already met,
+then the feature is automatically added.
+
+Default is C<true>.
+
 =item * C<-default>
 
 (Available since version 0.006)
@@ -425,11 +448,15 @@ under C<optional_feature> (thanks, miyagawa!)
 The phase of the prequisite(s). Should be one of: build, test, runtime,
 or develop.
 
+Default: C<runtime>
+
 =item * C<-relationship> (or C<-type>)
 
 The relationship of the prequisite(s). Should be one of: requires, recommends,
 suggests, or conflicts.
 
+Default: C<requires>
+
 =back
 
 =head1 SUPPORT
@@ -465,4 +492,10 @@ This software is copyright (c) 2013 by Karen Etheridge.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 CONTRIBUTOR
+
+=for stopwords Kent Fredric
+
+Kent Fredric <kentnl@cpan.org>
+
 =cut
